/*  
 *  xconvers - GTK+ client for amateur radio convers
 *  Copyright (C) 2000-2001 Joop Stakenborg <pa4tu@amsat.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 *  net.h
 */

#include <gtk/gtk.h>

#define MESSAGE_RX 1
#define MESSAGE_TX 2

void cvresolve(void);
gint resolvenonblock(void);
void cvconnect(gchar *where);
void cvdisconnect(void);
void rx(gpointer data, gint source, GdkInputCondition condition);
void tx(GString *message);
extern void maintext_add(gchar *msg, gint messagetype);
extern void tx_save(GString *history);